@@ -5,7 +5,7 @@ use strict;
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.00';
+	$VERSION = '1.02';
 }
 
 sub dummy { 'Brian' }
@@ -42,15 +42,15 @@ scheme.
 
 =head2 dummy
 
-Returns the dummy's name, in this case 'Build'
+Returns the dummy's name, in this case 'Brian'
 
 =head1 AUTHOR
 
-Adam Kennedy, C<< <cpan at ali.as> >>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SUPPORT
 
-No support is available for Build.
+No support is available for Brian.
 
 Sigh... no his head was NOT meant to come off like that.
 
@@ -60,7 +60,7 @@ L<PITA>, L<PITA::Scheme::Perl5::Build>, L<http://ali.as/pita/>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2006 Adam Kennedy, all rights reserved.
+Copyright 2006 - 2007 Adam Kennedy.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
